

class Shark:

    def hello_shark():
        print("hello shark")
    
    def shark_info():
        print("Sharks are a group of elasmobranch fish characterized by a cartilaginous \
            skeleton, five to seven gill slits on the sides of the head, and pectoral fins that \
            are not fused to the head.")